@@ -3,15 +3,9 @@ from __future__ import annotations
 
 from typing import ClassVar, Final
 
-from pyplumio import util
 from pyplumio.const import (
     ATTR_BOILER_SENSORS,
-    ATTR_FAN_POWER,
-    ATTR_FUEL_CONSUMPTION,
-    ATTR_FUEL_LEVEL,
-    ATTR_LOAD,
     ATTR_MODE,
-    ATTR_POWER,
     ATTR_REGDATA,
     ATTR_THERMOSTAT,
     ATTR_TRANSMISSION,
@@ -19,13 +13,18 @@ from pyplumio.const import (
 from pyplumio.exceptions import VersionError
 from pyplumio.frames import FrameTypes, Message
 from pyplumio.helpers.typing import DeviceDataType, MessageType
+from pyplumio.structures.fan_power import FanPowerStructure
 from pyplumio.structures.frame_versions import FrameVersionsStructure
+from pyplumio.structures.fuel_consumption import FuelConsumptionStructure
+from pyplumio.structures.fuel_level import FuelLevelStructure
 from pyplumio.structures.lambda_sensor import LambaSensorStructure
+from pyplumio.structures.load import LoadStructure
 from pyplumio.structures.mixers import MixersStructure
 from pyplumio.structures.modules import ModulesStructure
 from pyplumio.structures.output_flags import OutputFlagsStructure
 from pyplumio.structures.outputs import OutputsStructure
 from pyplumio.structures.pending_alerts import PendingAlertsStructure
+from pyplumio.structures.power import PowerStructure
 from pyplumio.structures.statuses import StatusesStructure
 from pyplumio.structures.temperatures import TemperaturesStructure
 from pyplumio.structures.thermostats import ThermostatsStructure
@@ -65,16 +64,16 @@ class SensorDataMessage(Message):
         sensors, offset = TemperaturesStructure(self).decode(message, offset, sensors)
         sensors, offset = StatusesStructure(self).decode(message, offset, sensors)
         sensors, offset = PendingAlertsStructure(self).decode(message, offset, sensors)
-        sensors[ATTR_FUEL_LEVEL] = message[offset]
-        sensors[ATTR_TRANSMISSION] = message[offset + 1]
-        sensors[ATTR_FAN_POWER] = util.unpack_float(message[offset + 2 : offset + 6])[0]
-        sensors[ATTR_LOAD] = message[offset + 6]
-        sensors[ATTR_POWER] = util.unpack_float(message[offset + 7 : offset + 11])[0]
-        sensors[ATTR_FUEL_CONSUMPTION] = util.unpack_float(
-            message[offset + 11 : offset + 15]
-        )[0]
-        sensors[ATTR_THERMOSTAT] = message[offset + 15]
-        sensors, offset = ModulesStructure(self).decode(message, offset + 16, sensors)
+        sensors, offset = FuelLevelStructure(self).decode(message, offset, sensors)
+        sensors[ATTR_TRANSMISSION] = message[offset]
+        sensors, offset = FanPowerStructure(self).decode(message, offset + 1, sensors)
+        sensors, offset = LoadStructure(self).decode(message, offset, sensors)
+        sensors, offset = PowerStructure(self).decode(message, offset, sensors)
+        sensors, offset = FuelConsumptionStructure(self).decode(
+            message, offset, sensors
+        )
+        sensors[ATTR_THERMOSTAT] = message[offset]
+        sensors, offset = ModulesStructure(self).decode(message, offset + 1, sensors)
         sensors, offset = LambaSensorStructure(self).decode(message, offset, sensors)
         sensors, offset = ThermostatsStructure(self).decode(message, offset, sensors)
         sensors, offset = MixersStructure(self).decode(message, offset, sensors)
